@@ -82,9 +82,6 @@ setGeneric("set.sdcProblem", function(object, type, input) {
 #' @param type a character vector of length 1 defining what to calculate|return|modify. Allowed types are:}
 #' \itemize{
 #' \item rule.freq: modify suppression status within \code{object} according to frequency suppression rule
-#' \item rule.nk: modify sdcStatus of \code{object} according to nk-dominance rule
-#' \item rule.p: modify sdcStatus of \code{object} according to p-percent rule
-#' \item rule.pq: modify sdcStatus of \code{object} according to pq-rule
 #' \item heuristicSolution: obtain a heuristic (greedy) solution to the problem defined by \code{object}
 #' \item cutAndBranch: solve a secondary cell suppression problem defined by \code{object} using cut and branch
 #' \item anonWorker: is used to solve the suppression problem depending on information provided with argument \code{input}
@@ -102,7 +99,7 @@ setGeneric("set.sdcProblem", function(object, type, input) {
 #' \item genStructuralCuts: calculate cuts that are absolute necessary for a valid solution of the secondary cell suppression problem
 #' @param input a list depending on argument \code{type}.}
 #' \itemize{
-#' \item a list (typically generated using genParaObj()) specifying parameters for primary cell suppression if argument \code{type} matches 'rule.freq', 'rule.nk' or 'rule.p'
+#' \item a list (typically generated using genParaObj()) specifying parameters for primary cell suppression if argument \code{type} matches 'rule.freq'
 #' \item a list if argument \code{type} matches 'heuristicSolution' having the following elements:
 #' \itemize{
 #' \item element 'aProb': an object of class \code{linProb} defining the attacker's problem
@@ -148,7 +145,7 @@ setGeneric("set.sdcProblem", function(object, type, input) {
 #' \item an empty list if argument \code{type} matches 'genStructuralCuts'
 #' @return information from objects of class \code{sdcProblem} depending on argument \code{type}
 #' \itemize{
-#' \item an object of class \code{sdcProblem} if argument \code{type} matches 'rule.freq', 'rule.nk', 'rule.p', 'cutAndBranch', 'anonWorker', 'ghmiter', 'ghmiter.supressQuader', 'ghmiter.suppressAdditionalQuader' or 'reduceProblem'
+#' \item an object of class \code{sdcProblem} if argument \code{type} matches 'rule.freq', 'cutAndBranch', 'anonWorker', 'ghmiter', 'ghmiter.supressQuader', 'ghmiter.suppressAdditionalQuader' or 'reduceProblem'
 #' \item a numeric vector with elements being 0 or 1 if argument \code{type} matches 'heuristicSolution'
 #' \item a list if argument \code{type} matches 'preprocess' having following elements:
 #' \itemize{
@@ -227,18 +224,6 @@ setGeneric("s_elapsedTime<-", function(object, value)
 setGeneric("c_rule_freq", function(object, input) {
   standardGeneric("c_rule_freq")
 })
-setGeneric("c_rule_nk", function(object, input) {
-  standardGeneric("c_rule_nk")
-})
-setGeneric("c_rule_nk", function(object, input) {
-  standardGeneric("c_rule_nk")
-})
-setGeneric("c_rule_p", function(object, input) {
-  standardGeneric("c_rule_p")
-})
-setGeneric("c_rule_pq", function(object, input) {
-  standardGeneric("c_rule_pq")
-})
 setGeneric("c_heuristic_solution", function(object, input) {
   standardGeneric("c_heuristic_solution")
 })
